orca r3477 - trunk/test/keystrokes/firefox
- From: joanied svn gnome org
- To: svn-commits-list gnome org
- Subject: orca r3477 - trunk/test/keystrokes/firefox
- Date: Fri, 18 Jan 2008 22:43:29 +0000 (GMT)
Author: joanied
Date: Fri Jan 18 22:43:28 2008
New Revision: 3477
URL: http://svn.gnome.org/viewvc/orca?rev=3477&view=rev
Log:
More updates to the regression tests.
Modified:
trunk/test/keystrokes/firefox/xul_role_push_button.py
trunk/test/keystrokes/firefox/xul_role_radio_button.py
trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py
Modified: trunk/test/keystrokes/firefox/xul_role_push_button.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_push_button.py (original)
+++ trunk/test/keystrokes/firefox/xul_role_push_button.py Fri Jan 18 22:43:28 2008
@@ -35,25 +35,42 @@
"u for Page Setup",
["BRAILLE LINE: 'Minefield Application Minefield Frame ToolBar AutoComplete Location $l'",
" VISIBLE: 'Location $l', cursor=10",
- "BRAILLE LINE: 'Page Setup Dialog Format for: Combo'",
- " VISIBLE: ' Combo', cursor=1",
+ "BRAILLE LINE: 'Minefield Application Page Setup Dialog'",
+ " VISIBLE: 'Page Setup Dialog', cursor=1",
+ "BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
+ " VISIBLE: '&=y Portrait RadioButton', cursor=1",
"SPEECH OUTPUT: 'Location autocomplete'",
"SPEECH OUTPUT: 'Location text '",
- "SPEECH OUTPUT: 'Format for: combo box'"]))
-
+ "SPEECH OUTPUT: ''",
+ "SPEECH OUTPUT: 'Page Setup %'",
+ "SPEECH OUTPUT: 'Format panel Orientation: panel'",
+ "SPEECH OUTPUT: 'Portrait selected radio button'"]))
+
sequence.append(WaitForWindowActivate("Page Setup",None))
########################################################################
-# Shift+tab again to move to the Apply push button.
-#
+# In the Page Setup dialog, shift+tab once to move to the page tabs.
+#
sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
sequence.append(utils.AssertPresentationAction(
- "Shift Tab to the Apply button",
- ["BRAILLE LINE: 'Page Setup Dialog Apply Button'",
- " VISIBLE: 'Page Setup Dialog Apply Button', cursor=19",
+ "Shift+Tab to page tabs",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog Format & Options Page'",
+ " VISIBLE: 'Format & Options Page', cursor=1",
"SPEECH OUTPUT: ''",
- "SPEECH OUTPUT: 'Apply button'"]))
+ "SPEECH OUTPUT: 'Format & Options page'"]))
+
+########################################################################
+# Shift+tab again to move to the OK push button.
+#
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
+sequence.append(utils.AssertPresentationAction(
+ "Shift+Tab to OK button",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog OK Button'",
+ " VISIBLE: 'OK Button', cursor=1",
+ "SPEECH OUTPUT: ''",
+ "SPEECH OUTPUT: 'OK button'"]))
########################################################################
# Do a basic "Where Am I" via KP_Enter.
@@ -63,21 +80,21 @@
sequence.append(PauseAction(3000))
sequence.append(utils.AssertPresentationAction(
"Basic Where Am I",
- ["BRAILLE LINE: 'Page Setup Dialog Apply Button'",
- " VISIBLE: 'Page Setup Dialog Apply Button', cursor=19",
- "SPEECH OUTPUT: 'Apply'",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog OK Button'",
+ " VISIBLE: 'OK Button', cursor=1",
+ "SPEECH OUTPUT: 'OK'",
"SPEECH OUTPUT: 'button'",
- "SPEECH OUTPUT: 'Alt a'"]))
+ "SPEECH OUTPUT: ''"]))
########################################################################
# Shift+tab again to move to the Cancel push button.
-#
+#
sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
sequence.append(utils.AssertPresentationAction(
- "Shift Tab to the Cancel button",
- ["BRAILLE LINE: 'Page Setup Dialog Cancel Button'",
- " VISIBLE: 'Page Setup Dialog Cancel Button', cursor=19",
+ "Shift+Tab to Cancel button",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog Cancel Button'",
+ " VISIBLE: 'Cancel Button', cursor=1",
"SPEECH OUTPUT: ''",
"SPEECH OUTPUT: 'Cancel button'"]))
@@ -89,11 +106,11 @@
sequence.append(PauseAction(3000))
sequence.append(utils.AssertPresentationAction(
"Basic Where Am I",
- ["BRAILLE LINE: 'Page Setup Dialog Cancel Button'",
- " VISIBLE: 'Page Setup Dialog Cancel Button', cursor=19",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog Cancel Button'",
+ " VISIBLE: 'Cancel Button', cursor=1",
"SPEECH OUTPUT: 'Cancel'",
"SPEECH OUTPUT: 'button'",
- "SPEECH OUTPUT: 'Alt c'"]))
+ "SPEECH OUTPUT: ''"]))
########################################################################
# Dismiss the dialog by pressing Space on the Cancel button and wait
Modified: trunk/test/keystrokes/firefox/xul_role_radio_button.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py (original)
+++ trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py Fri Jan 18 22:43:28 2008
@@ -12,7 +12,7 @@
########################################################################
# We wait for the focus to be on a blank Firefox window.
#
-sequence.append(WaitForWindowActivate("Minefield",None))
+sequence.append(WaitForWindowActivate("Minefield", None))
########################################################################
# Open the "File" menu and press U for the Page Setup dialog
@@ -36,13 +36,18 @@
"u for Page Setup",
["BRAILLE LINE: 'Minefield Application Minefield Frame ToolBar AutoComplete Location $l'",
" VISIBLE: 'Location $l', cursor=10",
- "BRAILLE LINE: 'Page Setup Dialog Format for: Combo'",
- " VISIBLE: ' Combo', cursor=1",
+ "BRAILLE LINE: 'Minefield Application Page Setup Dialog'",
+ " VISIBLE: 'Page Setup Dialog', cursor=1",
+ "BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
+ " VISIBLE: '&=y Portrait RadioButton', cursor=1",
"SPEECH OUTPUT: 'Location autocomplete'",
"SPEECH OUTPUT: 'Location text '",
- "SPEECH OUTPUT: 'Format for: combo box'"]))
-
-sequence.append(WaitForWindowActivate("Page Setup",None))
+ "SPEECH OUTPUT: ''",
+ "SPEECH OUTPUT: 'Page Setup %'",
+ "SPEECH OUTPUT: 'Format panel Orientation: panel'",
+ "SPEECH OUTPUT: 'Portrait selected radio button'"]))
+
+sequence.append(WaitForWindowActivate("Page Setup", None))
########################################################################
# Read the title bar with Orca+KP_ENTER
@@ -54,11 +59,29 @@
sequence.append(PauseAction(3000))
sequence.append(utils.AssertPresentationAction(
"Title Bar",
- ["BRAILLE LINE: 'Page Setup Dialog Format for: Combo'",
- " VISIBLE: ' Combo', cursor=1",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
+ " VISIBLE: '&=y Portrait RadioButton', cursor=1",
"SPEECH OUTPUT: 'Page Setup'"]))
########################################################################
+# Obtain the default button with Orca+KP_ENTER double clicked.
+#
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyPressAction(0, None, "KP_Insert"))
+sequence.append(KeyComboAction("KP_Enter"))
+sequence.append(KeyComboAction("KP_Enter"))
+sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
+sequence.append(PauseAction(3000))
+sequence.append(utils.AssertPresentationAction(
+ "Default button",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
+ " VISIBLE: '&=y Portrait RadioButton', cursor=1",
+ "BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
+ " VISIBLE: '&=y Portrait RadioButton', cursor=1",
+ "SPEECH OUTPUT: 'Page Setup'",
+ "SPEECH OUTPUT: 'Default button is OK'"]))
+
+########################################################################
# Dismiss the dialog by pressing Escape and wait for the location bar
# to regain focus.
#
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
--- trunk/test/keystrokes/firefox/xul_role_radio_button.py (original)
+++ trunk/test/keystrokes/firefox/xul_role_radio_button.py Fri Jan 18 22:43:28 2008
@@ -35,33 +35,31 @@
"u for Page Setup",
["BRAILLE LINE: 'Minefield Application Minefield Frame ToolBar AutoComplete Location $l'",
" VISIBLE: 'Location $l', cursor=10",
- "BRAILLE LINE: 'Page Setup Dialog Format for: Combo'",
- " VISIBLE: ' Combo', cursor=1",
+ "BRAILLE LINE: 'Minefield Application Page Setup Dialog'",
+ " VISIBLE: 'Page Setup Dialog', cursor=1",
+ "BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
+ " VISIBLE: '&=y Portrait RadioButton', cursor=1",
"SPEECH OUTPUT: 'Location autocomplete'",
"SPEECH OUTPUT: 'Location text '",
- "SPEECH OUTPUT: 'Format for: combo box'"]))
+ "SPEECH OUTPUT: ''",
+ "SPEECH OUTPUT: 'Page Setup %'",
+ "SPEECH OUTPUT: 'Format panel Orientation: panel'",
+ "SPEECH OUTPUT: 'Portrait selected radio button'"]))
+
+sequence.append(WaitForWindowActivate("Page Setup",None))
########################################################################
-# Tab twice to get to the Portrait radio button.
-#
+# In the Page Setup dialog, focus should already be on the "Portrait"
+# radio button. Right Arrow to the "Landscape" radio button.
+#
sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Tab"))
+sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
- "Tab",
- ["BRAILLE LINE: 'Page Setup Dialog Paper size: Combo'",
- " VISIBLE: ' Combo', cursor=1",
+ "Right Arrow to Landscape",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Landscape RadioButton'",
+ " VISIBLE: '&=y Landscape RadioButton', cursor=1",
"SPEECH OUTPUT: ''",
- "SPEECH OUTPUT: 'Paper size: combo box'"]))
-
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Tab"))
-sequence.append(utils.AssertPresentationAction(
- "Tab",
- ["BRAILLE LINE: 'Page Setup Dialog &=y Orientation: Portrait RadioButton'",
- " VISIBLE: '&=y Orientation: Portrait RadioB', cursor=1",
- "SPEECH OUTPUT: ''",
- "SPEECH OUTPUT: 'Orientation:'",
- "SPEECH OUTPUT: 'Portrait selected radio button'"]))
+ "SPEECH OUTPUT: 'Landscape selected radio button'"]))
########################################################################
# Do a basic "Where Am I" via KP_Enter.
@@ -71,25 +69,25 @@
sequence.append(PauseAction(3000))
sequence.append(utils.AssertPresentationAction(
"Basic Where Am I",
- ["BRAILLE LINE: 'Page Setup Dialog &=y Orientation: Portrait RadioButton'",
- " VISIBLE: '&=y Orientation: Portrait RadioB', cursor=1",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Landscape RadioButton'",
+ " VISIBLE: '&=y Landscape RadioButton', cursor=1",
"SPEECH OUTPUT: 'Orientation:'",
- "SPEECH OUTPUT: 'Orientation: Portrait radio button'",
+ "SPEECH OUTPUT: 'Landscape radio button'",
"SPEECH OUTPUT: 'selected'",
- "SPEECH OUTPUT: 'item 1 of 4'",
- "SPEECH OUTPUT: 'Alt o'"]))
+ "SPEECH OUTPUT: ''",
+ "SPEECH OUTPUT: ''"]))
########################################################################
# Right Arrow to the "Reverse portrait" radio button.
#
sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Right"))
+sequence.append(KeyComboAction("Left"))
sequence.append(utils.AssertPresentationAction(
- "Right Arrow to radio button",
- ["BRAILLE LINE: 'Page Setup Dialog & y Reverse portrait RadioButton'",
- " VISIBLE: '& y Reverse portrait RadioButton', cursor=1",
+ "Left Arrow to Portrait",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
+ " VISIBLE: '&=y Portrait RadioButton', cursor=1",
"SPEECH OUTPUT: ''",
- "SPEECH OUTPUT: 'Reverse portrait not selected radio button'"]))
+ "SPEECH OUTPUT: 'Portrait selected radio button'"]))
########################################################################
# Do a basic "Where Am I" via KP_Enter.
@@ -99,12 +97,12 @@
sequence.append(PauseAction(3000))
sequence.append(utils.AssertPresentationAction(
"Basic Where Am I",
- ["BRAILLE LINE: 'Page Setup Dialog &=y Reverse portrait RadioButton'",
- " VISIBLE: '&=y Reverse portrait RadioButton', cursor=1",
- "SPEECH OUTPUT: ''",
- "SPEECH OUTPUT: 'Reverse portrait radio button'",
+ ["BRAILLE LINE: 'Minefield Application Page Setup Dialog ScrollPane Format Panel Orientation: Panel &=y Portrait RadioButton'",
+ " VISIBLE: '&=y Portrait RadioButton', cursor=1",
+ "SPEECH OUTPUT: 'Orientation:'",
+ "SPEECH OUTPUT: 'Portrait radio button'",
"SPEECH OUTPUT: 'selected'",
- "SPEECH OUTPUT: 'item 2 of 4'",
+ "SPEECH OUTPUT: ''",
"SPEECH OUTPUT: ''"]))
########################################################################
Modified: trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py
@@ -71,25 +69,25 @@
########################################################################
-# Right Arrow to the "Reverse portrait" radio button.
+# Left Arrow to return to the "Portrait" radio button.
#
sequence.append(utils.StartRecordingAction())
==============================================================================